==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/ORDERTERMS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ORDERTERMS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ORDERTERMS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PAYMENTTERM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FREIGHTTERM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SHIPVIA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FOBPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PAYBYMETHOD" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ORDERTERMS_Type", propOrder = {
    "paymentterm",
    "freightterm",
    "shipvia",
    "fobpoint",
    "paybymethod"
})
public class ORDERTERMS_Type {

    @XmlElement(name = "PAYMENTTERM")
    protected PAYMENTTERM paymentterm;
    @XmlElement(name = "FREIGHTTERM")
    protected FREIGHTTERM freightterm;
    @XmlElement(name = "SHIPVIA")
    protected SHIPVIA shipvia;
    @XmlElement(name = "FOBPOINT")
    protected FOBPOINT fobpoint;
    @XmlElement(name = "PAYBYMETHOD")
    protected PAYBYMETHOD paybymethod;

    /**
     * Obtient la valeur de la propriété paymentterm.
     * 
     * @return
     *     possible object is
     *     {@link PAYMENTTERM }
     *     
     */
    public PAYMENTTERM getPAYMENTTERM() {
        return paymentterm;
    }

    /**
     * Définit la valeur de la propriété paymentterm.
     * 
     * @param value
     *     allowed object is
     *     {@link PAYMENTTERM }
     *     
     */
    public void setPAYMENTTERM(PAYMENTTERM value) {
        this.paymentterm = value;
    }

    /**
     * Obtient la valeur de la propriété freightterm.
     * 
     * @return
     *     possible object is
     *     {@link FREIGHTTERM }
     *     
     */
    public FREIGHTTERM getFREIGHTTERM() {
        return freightterm;
    }

    /**
     * Définit la valeur de la propriété freightterm.
     * 
     * @param value
     *     allowed object is
     *     {@link FREIGHTTERM }
     *     
     */
    public void setFREIGHTTERM(FREIGHTTERM value) {
        this.freightterm = value;
    }

    /**
     * Obtient la valeur de la propriété shipvia.
     * 
     * @return
     *     possible object is
     *     {@link SHIPVIA }
     *     
     */
    public SHIPVIA getSHIPVIA() {
        return shipvia;
    }

    /**
     * Définit la valeur de la propriété shipvia.
     * 
     * @param value
     *     allowed object is
     *     {@link SHIPVIA }
     *     
     */
    public void setSHIPVIA(SHIPVIA value) {
        this.shipvia = value;
    }

    /**
     * Obtient la valeur de la propriété fobpoint.
     * 
     * @return
     *     possible object is
     *     {@link FOBPOINT }
     *     
     */
    public FOBPOINT getFOBPOINT() {
        return fobpoint;
    }

    /**
     * Définit la valeur de la propriété fobpoint.
     * 
     * @param value
     *     allowed object is
     *     {@link FOBPOINT }
     *     
     */
    public void setFOBPOINT(FOBPOINT value) {
        this.fobpoint = value;
    }

    /**
     * Obtient la valeur de la propriété paybymethod.
     * 
     * @return
     *     possible object is
     *     {@link PAYBYMETHOD }
     *     
     */
    public PAYBYMETHOD getPAYBYMETHOD() {
        return paybymethod;
    }

    /**
     * Définit la valeur de la propriété paybymethod.
     * 
     * @param value
     *     allowed object is
     *     {@link PAYBYMETHOD }
     *     
     */
    public void setPAYBYMETHOD(PAYBYMETHOD value) {
        this.paybymethod = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/ORDERTERMS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ORDERTERMS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ORDERTERMS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PAYMENTTERM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FREIGHTTERM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SHIPVIA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FOBPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PAYBYMETHOD" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ORDERTERMS_Type", propOrder = {
    "paymentterm",
    "freightterm",
    "shipvia",
    "fobpoint",
    "paybymethod"
})
public class ORDERTERMS_Type {

    @XmlElement(name = "PAYMENTTERM")
    protected PAYMENTTERM paymentterm;
    @XmlElement(name = "FREIGHTTERM")
    protected FREIGHTTERM freightterm;
    @XmlElement(name = "SHIPVIA")
    protected SHIPVIA shipvia;
    @XmlElement(name = "FOBPOINT")
    protected FOBPOINT fobpoint;
    @XmlElement(name = "PAYBYMETHOD")
    protected PAYBYMETHOD paybymethod;

    /**
     * Gets the value of the paymentterm property.
     * 
     * @return
     *     possible object is
     *     {@link PAYMENTTERM }
     *     
     */
    public PAYMENTTERM getPAYMENTTERM() {
        return paymentterm;
    }

    /**
     * Sets the value of the paymentterm property.
     * 
     * @param value
     *     allowed object is
     *     {@link PAYMENTTERM }
     *     
     */
    public void setPAYMENTTERM(PAYMENTTERM value) {
        this.paymentterm = value;
    }

    /**
     * Gets the value of the freightterm property.
     * 
     * @return
     *     possible object is
     *     {@link FREIGHTTERM }
     *     
     */
    public FREIGHTTERM getFREIGHTTERM() {
        return freightterm;
    }

    /**
     * Sets the value of the freightterm property.
     * 
     * @param value
     *     allowed object is
     *     {@link FREIGHTTERM }
     *     
     */
    public void setFREIGHTTERM(FREIGHTTERM value) {
        this.freightterm = value;
    }

    /**
     * Gets the value of the shipvia property.
     * 
     * @return
     *     possible object is
     *     {@link SHIPVIA }
     *     
     */
    public SHIPVIA getSHIPVIA() {
        return shipvia;
    }

    /**
     * Sets the value of the shipvia property.
     * 
     * @param value
     *     allowed object is
     *     {@link SHIPVIA }
     *     
     */
    public void setSHIPVIA(SHIPVIA value) {
        this.shipvia = value;
    }

    /**
     * Gets the value of the fobpoint property.
     * 
     * @return
     *     possible object is
     *     {@link FOBPOINT }
     *     
     */
    public FOBPOINT getFOBPOINT() {
        return fobpoint;
    }

    /**
     * Sets the value of the fobpoint property.
     * 
     * @param value
     *     allowed object is
     *     {@link FOBPOINT }
     *     
     */
    public void setFOBPOINT(FOBPOINT value) {
        this.fobpoint = value;
    }

    /**
     * Gets the value of the paybymethod property.
     * 
     * @return
     *     possible object is
     *     {@link PAYBYMETHOD }
     *     
     */
    public PAYBYMETHOD getPAYBYMETHOD() {
        return paybymethod;
    }

    /**
     * Sets the value of the paybymethod property.
     * 
     * @param value
     *     allowed object is
     *     {@link PAYBYMETHOD }
     *     
     */
    public void setPAYBYMETHOD(PAYBYMETHOD value) {
        this.paybymethod = value;
    }

}
